mysql.stmt.bind_out.Output_Bind

Package mysql :: Package stmt :: Module bind_out :: Class Output_Bind |
[hide private]
[frames] | no frames]

# Class Output_Bind

    object --+
             |
            Output_Bind

Known Subclasses:
  Base_Out_Stream, Base_Out_String, Out_Big_Int, Out_Bit, Out_Tiny_Int, Out_Date, Out_Date_Time, Out_Decimal, Out_Double, Out_Float, Out_Int, Out_Null, Out_Small_Int, Out_Time, Out_Timestamp, Out_U_Big_Int, Out_U_Int, Out_U_Small_Int, Out_U_Tiny_Int, Out_Year

Base output binding class.

The constructor takes at least 2 arguments The first is the object in which to set the value. The second is the name of the parameter to set in the object.

Internally, the Statement object calls `Output_Bind.load` on all bound outputs during each call to `fetch`.

Instance Methods | [hide private]
`` | __init__(...) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
`` | __new__(T, S, ...) Returns a new object with type S, a subtype of T...
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
`` | __pyx_vtable__ = `<PyCObject object at 0x852e878>`

Instance Variables | [hide private]
`` | _buffer The location where the data is stored.
`` | _buffer_length The size of memory allocated for _buffer.
`` | _buffer_type The type of buffer (from enum_field_types).
`` | _is_unsigned Whether or not the value is unsigned.
`` | _what The variable name to set in _who with the value.
`` | _who The object what wants the value.
`` | error = `<member 'error' of 'mysql.stmt.bind_out.Output_Bind'...` Whether or not there was an error retrieving the value.
`` | is_null = `<member 'is_null' of 'mysql.stmt.bind_out.Output_Bin...` Whether or not the value is null.
`` | length = `<member 'length' of 'mysql.stmt.bind_out.Output_Bind...` The length of the value as reported by MySQL.

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(...) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__

### __new__(T, S, ...) |
    Returns:
        a new object with type S, a subtype of T
Overrides: object.__new__

Class Variable Details | [hide private]

    ### __pyx_vtable__ Value:
        <PyCObject object at 0x852e878>

Instance Variable Details | [hide private]

### _buffer The location where the data is stored. (Part of MYSQL_BIND structure.) (C only.)

### _buffer_length The size of memory allocated for _buffer. This is set in __init__ by the user. (Part of MYSQL_BIND structure.) (C only.)

### _buffer_type The type of buffer (from enum_field_types). (Part of MYSQL_BIND structure.) (C only.)

### _is_unsigned Whether or not the value is unsigned. This should be set to 1 in the __new__ method if necessary. (Part of MYSQL_BIND structure.) (C only.)

### _what The variable name to set in _who with the value. This is set in __init__. (C only.)

### _who The object what wants the value. This is set in __init__. (C only.)

    ### error Whether or not there was an error retrieving the value. (Part of MYSQL_BIND structure.) (Read only.) Value:
        <member 'error' of 'mysql.stmt.bind_out.Output_Bind' objects>

    ### is_null Whether or not the value is null. (Part of MYSQL_BIND structure.) (Read only.) Value:
        <member 'is_null' of 'mysql.stmt.bind_out.Output_Bind' objects>

    ### length The length of the value as reported by MySQL. (Part of MYSQL_BIND structure.) (Read only.) Value:
        <member 'length' of 'mysql.stmt.bind_out.Output_Bind' objects>